#!/bin/sh
##------------------------------------------------------------------------------
## local: opt\files\srv\www\admin\macfilter.cgi
## fli4l: srv/www/admin/macfilter.cgi
## DE: OPT_HTTPD Webadmin Webseite fr MACFilter
## EN: OPT_HTTPD webadmin page for MACFilter
##------------------------------------------------------------------------------
##
## Creation:       01.11.2008  Florian Schlgl <Florian_Schloegl.Wolfsteam@web.de>
## Last modified:  03.12.2008  Florian Schlgl <Florian_Schloegl.Wolfsteam@web.de>
## Version:        1.1.0-1.1.1
##
##------------------------------------------------------------------------------
## Files:    /var/run/macfilter.conf
##------------------------------------------------------------------------------
. /srv/www/include/cgi-helper
. /var/run/macfilter.conf

if [ -f /usr/local/bin/macfilter_log.sh ]
then
    /usr/local/bin/macfilter_log.sh "-D" "[macfilter.cgi] action: $FORM_action"
fi

# DE: Rechte kontollieren
# EN: check rights
: ${FORM_action:=view}
check_rights "macfilter" "$FORM_action"

show_html_header "$_html_header"

#-------------------------------------------------------------------------------
# DE: Aktion durchfhren
# EN: perform action
#-------------------------------------------------------------------------------
case $FORM_action in
    #----------------------------------------
    # DE: Mac hinzufgen
    # EN: add mac
    #----------------------------------------
    add)
        /usr/local/bin/macfilter.sh "--add" "$FORM_mac" 
        show_info "$_info_add_mac_header" "$_info_add_mac_text<CENTER><A href=\"$myname\">$_cmd_go_back</A></CENTER>"
        echo "<META http-equiv=\"refresh\" content=\"5; URL=$myname\">"
    ;;
    
    #----------------------------------------
    # DE: Mac entfernen
    # EN:remove mac
    #----------------------------------------
    remove)
        /usr/local/bin/macfilter.sh "--remove" "$FORM_mac"
        show_info "$_info_remove_mac_header" "$_info_remove_mac_text<CENTER><A href=\"$myname\">$_cmd_go_back</A></CENTER>"
        echo "<META http-equiv=\"refresh\" content=\"5; URL=$myname\">"
    ;;
    
    #----------------------------------------
    # DE: Macfilter starten
    # EN: start macfilter
    #----------------------------------------
    startfilter)
        if [ `/usr/local/bin/macfilter.sh --state` = "stopped" ]
        then
            /usr/local/bin/macfilter.sh "--startfilter"
            show_info "$_info_starting_header" "$_info_starting_text<CENTER><A href=\"$myname\">$_cmd_go_back</A></CENTER>"
        else
            show_error "$_error_already_running_header" "$_error_already_running_text<CENTER><A href=\"$myname\">$_cmd_go_back</A></CENTER>"
        fi
        echo "<META http-equiv=\"refresh\" content=\"5; URL=$myname\">"
    ;;
    
    #----------------------------------------
    # DE: Macfilter anhalten
    # EN: stop macfilter
    #----------------------------------------
    stopfilter)
        /usr/local/bin/macfilter.sh "--stopfilter"
        show_info "$_info_stopping_header" "$_info_stopping_text<CENTER><A href=\"$myname\">$_cmd_go_back</A></CENTER>"
        echo "<META http-equiv=\"refresh\" content=\"5; URL=$myname\">"
    ;;
    
    #----------------------------------------
    # DE: Auf Whitelist stellen
    # EN: set to whitelist
    #----------------------------------------
    whitelist)
        if [ `/usr/local/bin/macfilter.sh --state` = "stopped" ]
        then
            check_rights "macfilter" "startfilter"
            /usr/local/bin/macfilter.sh --"startfilter"
            show_info "$_info_starting_header" "$_info_starting_text"
            echo "<p/>"
        fi
        /usr/local/bin/macfilter.sh --"whitelist"
        show_info "$_info_whitelist_header" "$_info_whitelist_text<CENTER><A href=\"$myname\">$_cmd_go_back</A></CENTER>"
        echo "<META http-equiv=\"refresh\" content=\"5; URL=$myname\">"
    ;;
    
    #----------------------------------------
    # DE: Auf Blacklist stellen
    # EN: set to blacklist
    #----------------------------------------
    blacklist)
        if [ `/usr/local/bin/macfilter.sh --state` = "stopped" ]
        then
            check_rights "macfilter" "startfilter"
            /usr/local/bin/macfilter.sh --"startfilter"
            show_info "$_info_starting_header" "$_info_starting_text"
            echo "<p/>"
        fi
        /usr/local/bin/macfilter.sh --"blacklist"
        show_info "$_info_blacklist_header" "$_info_blacklist_text<CENTER><A href=\"$myname\">$_cmd_go_back</A></CENTER>"
        echo "<META http-equiv=\"refresh\" content=\"5; URL=$myname\">"
    ;;

    #-------------------------------------------------------------------------------
    # DE: HTML ausgeben
    # EN: print HTML
    #-------------------------------------------------------------------------------
    view)
        case `/usr/local/bin/macfilter.sh --state` in
            blacklist)
                show_tab_header  "$_tab_blacklist"  no \
                                 "$_tab_whitelist"  "$myname?action=whitelist" \
                                 "$_tab_stop"       "$myname?action=stopfilter"
            ;;
            
            whitelist)
                show_tab_header  "$_tab_blacklist"  "$myname?action=blacklist" \
                                 "$_tab_whitelist"  no \
                                 "$_tab_stop"       "$myname?action=stopfilter"
            ;;
            
            stopped)
                show_tab_header  "$_tab_blacklist"  "$myname?action=blacklist" \
                                 "$_tab_whitelist"  "$myname?action=whitelist" \
                                 "$_tab_stop"       no
            ;;
            
            *)
                show_error "$_error_unknown_state_header" "$_error_unknown_state_text"
                
                show_tab_header  "$_tab_blacklist"  "$myname?action=blacklist" \
                                 "$_tab_whitelist"  "$myname?action=whitelist" \
                                 "$_tab_stop"       "$myname?action=stopfilter"
            ;;
        esac
        
        ##-------------------------------------------------------------------------------
        ## DE: MAC Addressen Tabelle ausgeben
        ## EN: print MAC address table
        ##-------------------------------------------------------------------------------
        echo "<TABLE class=\"normtable\">
  <TR>
    <TH align=\"left\">$_table_header_mac</TH>
    <TH align=\"left\">$_table_header_action</TH>
  </TR>"

        macfilter_macs=`/usr/local/bin/macfilter.sh --list`
        for macfilter_mac in $macfilter_macs
        do
            echo "  <FORM action=\"$myname\" method=\"get\"><TR>
    <INPUT type=\"hidden\" name=\"action\" value=\"remove\">
    <INPUT type=\"hidden\" name=\"mac\" value=\"$macfilter_mac\">
    <TD align=\"left\">$macfilter_mac</TD>
    <TD align=\"center\">
      <INPUT type=\"submit\" value=\"$_table_action_remove\" class=\"actions\">
    </TD>
  </TR></FORM>"
        done
          
        echo "  <FORM action=\"$myname\" method=\"get\"><TR>
    <INPUT type=\"hidden\" name=\"action\" value=\"add\">
    <TD align=\"left\">
      <INPUT type=\"text\" name=\"mac\" value=\"\">
    </TD>
    <TD align=\"center\"><INPUT type=\"submit\" value=\"$_table_action_add\" class=\"actions\"></TD>
  </TR></FORM>
</TABLE>"
        
        show_tab_footer
    ;;
    
    #----------------------------------------
    # DE: unbekannte Aktion
    # EN: unknown action
    #----------------------------------------
    *)
        show_error "$_error_unknown_action_header" "$_error_unknown_action<CENTER><A href=\"$myname\">$_cmd_go_back</A></CENTER>"
        echo "<META http-equiv=\"refresh\" content=\"2; URL=$myname\">"
    ;;
esac

#----------------------------------------
# DE: Ende des Dokuments ausgeben
# EN: print end of doc
#----------------------------------------
show_html_footer
##------------------------------------------------------------------------------
# macfilter.cgi -- EOF ---
##------------------------------------------------------------------------------