#!/bin/sh
##------------------------------------------------------------------------------
## local: opt\files\usr\local\bin\macfilter.sh
## fli4l: usr/local/bin/macfilter.sh
## DE: start, stop, hinzufgen und entfernen von MACs
## EN: start, stop, add/remove of MACs
##------------------------------------------------------------------------------
##
## Creation:       01.11.2008  Florian Schlgl <Florian_Schloegl.Wolfsteam@web.de>
## Last modified:  03.12.2008  Florian Schlgl <Florian_Schloegl.Wolfsteam@web.de>
## Version:        1.1.0-1.1.1
##
## Copyright (c) 2008 Florian Schlgl <Florian_Schloegl.Wolfsteam@web.de>
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##------------------------------------------------------------------------------
## Parameter:   <$1 = "--startfilter">        MACFilter starten
##              <$1 = "--stopfilter">         MACFilter anhalten
##              <$1 = "--blacklist">          MACs fr Blacklist benutzen
##              <$1 = "--whitelist">          MACs fr Whitelist benutzen
##              <$1 = "--add"> <$2 = MAC>     MAC hinzufgen
##              <$1 = "--remove"> <$2 = MAC>  MAC entfernen
##              <$1 = "--state">              Status von MACFilter ausgeben
##              <$1 = "--list">               Liste mit den MAC Adressen ausgeben
##              <$1 = "--listtype">           Liste mit den MAC Adressen ausgeben
## Files:    /var/run/macfilter.conf
##------------------------------------------------------------------------------
. /etc/boot.d/base-helper
. /etc/rc.d/fwrules-helper
. /srv/www/include/cgi-helper
. /var/run/macfilter.conf

thisfile="macfilter.sh"

#----------------------------------------------------------------------------
# DE: Debug Hilfsmethode
# EN: debug helping method
#----------------------------------------------------------------------------
macfilter_do_log() {
    if [ -f /usr/local/bin/macfilter_log.sh ]
    then
        /usr/local/bin/macfilter_log.sh $@
    fi
}
macfilter_log_warn() {
    macfilter_do_log "-W" "$@"
}
macfilter_log_info() {
    macfilter_do_log "-I" "$@"
}
macfilter_log_debug() {
    macfilter_do_log "-D" "[$thisfile] $@"
}


#----------------------------------------------------------------------------
# DE: Hauptmethode
# EN: main method
#----------------------------------------------------------------------------

macfilter_log_debug "Param: $@"

case $1 in
    #----------------------------------------
    # DE: MACFilter starten
    # EN: start MACFilter
    #----------------------------------------
    --startfilter)
        if [ `$thisfile --state` = "stopped" ]
        then
            macfilter_log_info "start filter"
            add_rule filter macfilter_main "any any macfilter_list"
        else
            macfilter_state=`$thisfile --state`
            macfilter_log_info "already running ($macfilter_state)"
        fi
    ;;
    
    #----------------------------------------
    # DE: MACFilter anhalten
    # EN: stop MACFilter
    #----------------------------------------
    --stopfilter)
        macfilter_log_info "stop filter"
        del_rule filter macfilter_main "any any macfilter_list"
    ;;
    
    #----------------------------------------
    # DE: MACFilter als Blacklist benutzen
    # EN: use MACFilter as blacklist
    #----------------------------------------
    --blacklist)
        macfilter_log_info "set to blacklist"
        
        for macfilter_mac in `$thisfile --list`
        do
            macfilter_log_debug "MAC: $macfilter_mac"
            del_rule filter macfilter_list "mac:$macfilter_mac any RETURN" "MAC:$macfilter_mac"
            del_rule filter macfilter_list "mac:$macfilter_mac any DROP" "MAC:$macfilter_mac"
            add_rule filter macfilter_list "mac:$macfilter_mac any DROP" "MAC:$macfilter_mac"
        done
        
        if [ `$thisfile --listtype` = "whitelist" ]
        then
            del_rule filter macfilter_list "any any DROP" "Whitelist"
        fi
    ;;
    
    #----------------------------------------
    # DE: MACFilter als Whitelist benutzen
    # EN: use MACFilter as whitelist
    #----------------------------------------
    --whitelist)
        macfilter_log_info "set to whitelist"
        
        for macfilter_mac in `$thisfile --list`
        do
            macfilter_log_debug "MAC: $macfilter_mac"
            del_rule filter macfilter_list "mac:$macfilter_mac any DROP" "MAC:$macfilter_mac"
            del_rule filter macfilter_list "mac:$macfilter_mac any RETURN" "MAC:$macfilter_mac"
            add_rule filter macfilter_list "mac:$macfilter_mac any RETURN" "MAC:$macfilter_mac"
        done
        
        add_rule filter macfilter_list "any any DROP" "Whitelist"
    ;;
    
    #----------------------------------------
    # DE: MAC der Liste hinzufgen
    # EN: add MAC to list
    #----------------------------------------
    --add)
        if [ `$thisfile --listtype` = "blacklist" ]
        then
            macfilter_log_info "add $2 to blacklist"
            ins_rule filter macfilter_list "mac:$2 any DROP" 1 "MAC:$2"
        else
            macfilter_log_info "add $2 to whitelist"
            ins_rule filter macfilter_list "mac:$2 any RETURN" 1 "MAC:$2"
        fi
    ;;
    
    #----------------------------------------
    # DE: MAC der Liste entfernen
    # EN: remove MAC to list
    #----------------------------------------
    --remove)
        if [ `$thisfile --listtype` = "blacklist" ]
        then
            macfilter_log_info "remove $2 from blacklist"
            del_rule filter macfilter_list "mac:$2 any DROP" "MAC:$2"
        else
            macfilter_log_info "remove $2 from whitelist"
            del_rule filter macfilter_list "mac:$2 any RETURN" "MAC:$2"
        fi
    ;;
    
    #----------------------------------------
    # DE: Status von MACFilter ausgeben
    # EN: return state of MACfilter
    #----------------------------------------
    --state)
        if [ `iptables -nvL macfilter_list | grep "Chain" | cut -dr -f2 | cut -b8-` = "0" ]
        then
            echo "stopped"
        else
            echo `$thisfile --listtype`
        fi
    ;;
    
    #----------------------------------------
    # DE: List mit den MAC Adressen ausgeben
    # EN: return list with mac address
    #----------------------------------------
    --list)
        echo `iptables -nvL macfilter_list | grep "MAC" | cut -dM -f2 | cut -b4-20`
    ;;
    
    #----------------------------------------
    # DE: List mit den MAC Adressen ausgeben
    # EN: return list with mac address
    #----------------------------------------
    --listtype)
        if [ `iptables -nvL macfilter_list | grep "Whitelist" -c` = "0" ]
        then
            echo "blacklist"
        else
            echo "whitelist"
        fi
    ;;
    
    #----------------------------------------
    # DE: ungltiger Parameter
    # EN: invalid Parameter
    #----------------------------------------
    --help)
        macfilter_log_debug "print help"
        echo "commands:"
        echo "  --startfilter           start MACFilter"
        echo "  --stopfilter            stop MACFilter"
        echo "  --blacklist             set MACFilter as blacklist"
        echo "  --whitelist             set MACFilter as whitelist"
        echo "  --add <macaddress>      add the given MAC address to the list"
        echo "  --remove <macaddress>   remove the given MAC address from the list"
        echo "  --state                 state of MACFilter"
        echo "  --list                  list of MAC address"
        echo "  --listtype              blacklist or whitelist"
        echo "  --help                  print this help"
    ;;
    
    #----------------------------------------
    # DE: ungltiger Parameter
    # EN: invalid Parameter
    #----------------------------------------
    *)
        macfilter_log_warn "unknown param ('$@')"
        echo "Bad argument '$1'"
        echo "Try '$thisfile --help' for more information"
    ;;
esac
#----------------------------------------------------------------------------
# macfilter.sh -- EOF ---
#----------------------------------------------------------------------------